@@ -16,8 +16,6 @@ from torchvision.models.detection.faster_rcnn import FastRCNNPredictor
 from torchvision.models.detection.mask_rcnn import MaskRCNNPredictor
 
 import pytorch_lightning as pl
-from pytorch_lightning.callbacks import ModelCheckpoint
-from pytorch_lightning.loggers import TensorBoardLogger
 
 import torchmetrics
 from torchmetrics.detection.mean_ap import MeanAveragePrecision
@@ -27,7 +25,7 @@ from typing import List, Union
 import gc
 import matplotlib.pyplot as plt
 import numpy as np 
-# import cv2
+import cv2
 
 # Necessary for creating our images.
 from skimage.draw import line_aa
