@@ -16,22 +16,21 @@ from torchvision.models.detection.faster_rcnn import FastRCNNPredictor
 from torchvision.models.detection.mask_rcnn import MaskRCNNPredictor
 
 import pytorch_lightning as pl
-from pytorch_lightning.callbacks import ModelCheckpoint
-from pytorch_lightning.loggers import TensorBoardLogger
 
 import torchmetrics
 from torchmetrics.detection.mean_ap import MeanAveragePrecision
 
-# Standard imports. 
+# Standard imports.
 from typing import List, Union
 import gc
 import matplotlib.pyplot as plt
-import numpy as np 
+import numpy as np
 import cv2
 
 # Necessary for creating our images.
 from skimage.draw import line_aa
 
+
 class DoubleConv(nn.Module):
     """
     A double convolution module used to extract features.
@@ -258,44 +257,43 @@ class UNET(nn.Module):
         return x
 
 
-def get_fasterrcnn(num_classes = 4, pretrained = True):
-    """A function for loading the PyTorch implimentation of FasterRCNN. 
-    See here for documentation on the input and output specifics: 
+def get_fasterrcnn(num_classes=4, pretrained=True):
+    """A function for loading the PyTorch implimentation of FasterRCNN.
+    See here for documentation on the input and output specifics:
     https://pytorch.org/vision/stable/models/faster_rcnn.html
 
     Args:
         num_classes (int): number of output classes desired.
-        pretrained (bool): whether or not to load a model pretrained on the 
+        pretrained (bool): whether or not to load a model pretrained on the
     """
 
     # load Faster RCNN pre-trained model
-    if pretrained: 
-        model = torchvision.models.detection.fasterrcnn_resnet50_fpn(weights='DEFAULT')
-    else: 
+    if pretrained:
+        model = torchvision.models.detection.fasterrcnn_resnet50_fpn(weights="DEFAULT")
+    else:
         model = torchvision.models.detection.fasterrcnn_resnet50_fpn(weights=None)
-    
-    # get the number of input features 
+
+    # get the number of input features
     in_features = model.roi_heads.box_predictor.cls_score.in_features
     # define a new head for the detector with required number of classes
-    model.roi_heads.box_predictor = FastRCNNPredictor(in_features, num_classes) 
+    model.roi_heads.box_predictor = FastRCNNPredictor(in_features, num_classes)
 
     return model
 
 
-
-def get_maskrcnn(num_classes = 4, pretrained = True):
-        """A function for loading the PyTorch implimentation of MaskRCNN. 
-    See here for documentation on the input and output specifics: 
+def get_maskrcnn(num_classes=4, pretrained=True):
+    """A function for loading the PyTorch implimentation of MaskRCNN.
+    See here for documentation on the input and output specifics:
     https://pytorch.org/vision/0.12/generated/torchvision.models.detection.maskrcnn_resnet50_fpn.html
 
     Args:
         num_classes (int): number of output classes desired.
-        pretrained (bool): whether or not to load a model pretrained on the 
+        pretrained (bool): whether or not to load a model pretrained on the
     """
-    
-    if pretrained: 
-        model = torchvision.models.detection.maskrcnn_resnet50_fpn(pretrained='DEFAULT')
-    else: 
+
+    if pretrained:
+        model = torchvision.models.detection.maskrcnn_resnet50_fpn(pretrained="DEFAULT")
+    else:
         model = torchvision.models.detection.maskrcnn_resnet50_fpn(weights=None)
 
     # Get number of input features for the classifier.
@@ -309,8 +307,8 @@ def get_maskrcnn(num_classes = 4, pretrained = True):
 
     hidden_layer = 256
     # Replace the pre-trained mask predictor head with a new one.
-    model.roi_heads.mask_predictor = MaskRCNNPredictor(in_features_mask,
-                                                       hidden_layer,
-                                                       num_classes)
+    model.roi_heads.mask_predictor = MaskRCNNPredictor(
+        in_features_mask, hidden_layer, num_classes
+    )
 
-    return model
\ No newline at end of file
+    return model
